==> org.eclipse.riena.security.services.source_1.2.0.v20091214_1_2_0_0.jar: org/eclipse/riena/security/sessionservice/ISessionStore.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.security.sessionservice;

import java.security.Principal;

import org.eclipse.riena.security.common.session.Session;

/**
 * Store for sessions
 * 
 */
public interface ISessionStore {

	String SESSION_STORE_ID = "spirit.securityimplementation.server.SessionStore"; //$NON-NLS-1$

	/**
	 * reads the sessions for one principal from the store
	 * 
	 * @param principal
	 *            principal for which sessions should be read
	 * @return returns an array of session objects
	 */
	Session[] read(Principal principal);

	/**
	 * reads the session entry object for a session
	 * 
	 * @param session
	 * @return session entry
	 */
	SessionEntry read(Session session);

	/**
	 * writes or update a session entry
	 * 
	 * @param entry
	 *            session entry to write
	 */
	void write(SessionEntry entry);

	/**
	 * deletes the session entries for a session
	 * 
	 * @param session
	 */
	void delete(Session session);

	/**
	 * deletes the session entries for a principal
	 * 
	 * @param principal
	 */
	void delete(Principal principal);

}

==> org.eclipse.riena.security.services.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/security/sessionservice/ISessionStore.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.security.sessionservice;

import java.security.Principal;

import org.eclipse.riena.security.common.session.Session;

/**
 * The implementation of ISessionStore stores the session (preferable
 * persistently). Riena supplies a simple default implementation which store the
 * session objects in the JVM memory.
 * 
 * Its better to replace this default implementation with a custom
 * implementation that store the data in a persistent store so that they can be
 * retrieved again when the server has to be restarted and so that they can be
 * shared servers (if there is more than one).
 * 
 */
public interface ISessionStore {

	//	String SESSION_STORE_ID = "riena.securityimplementation.server.SessionStore"; //$NON-NLS-1$

	/**
	 * reads the sessions for one principal from the store TODO should be
	 * Subject see bug 312640
	 * 
	 * @param principal
	 *            principal for which sessions should be read
	 * @return an array of session objects
	 * @deprecated
	 */
	Session[] read(Principal principal);

	/**
	 * reads the session entry object for a session
	 * 
	 * @param session
	 * @return session entry
	 */
	SessionEntry read(Session session);

	/**
	 * writes or update a session entry
	 * 
	 * @param entry
	 *            session entry to write
	 */
	void write(SessionEntry entry);

	/**
	 * deletes the session entries for a session
	 * 
	 * @param session
	 */
	void delete(Session session);

	/**
	 * deletes the session entries for a principal
	 * 
	 * @param principal
	 * @deprecated
	 */
	void delete(Principal principal);

}
